@@ -4,9 +4,12 @@ import time
 import traceback
 from typing import Any, Dict, List, Optional, Tuple, Union
 
+from ._debug import info as debug_info  # noqa: F401
+from ._debug import log
 from ._version import __author__, __version__  # noqa: F401
 from .helpers import MONITOR_MANUFACTURER_CODES  # noqa: F401
-from .helpers import ScreenBrightnessError, flatten_list, logarithmic_range
+from .helpers import ScreenBrightnessError, logarithmic_range
+from .helpers import flatten_list  # noqa: F401  - deprecated.
 
 
 def get_brightness(
@@ -99,16 +102,18 @@ def set_brightness(
             output = []
             for monitor in monitors:
                 identifier = Monitor.get_identifier(monitor)[1]
-                output.append(
-                    set_brightness(
-                        get_brightness(display=identifier)[0] + value,
-                        display=identifier,
-                        force=force,
-                        verbose_error=verbose_error,
-                        no_return=no_return
-                    )
+                tmp = set_brightness(
+                    get_brightness(display=identifier)[0] + value,
+                    display=identifier,
+                    force=force,
+                    verbose_error=verbose_error,
+                    no_return=no_return
                 )
-            return flatten_list(output)
+                if isinstance(tmp, list):
+                    output += tmp
+                else:  # otherwise the output should be None
+                    output.append(tmp)
+            return output
 
         value += get_brightness(display=Monitor.get_identifier(monitors[0])[1])[0]
     else:
@@ -181,9 +186,14 @@ def fade_brightness(
     def fade(start, finish, increment, monitor):
         range_func = logarithmic_range if logarithmic else range
 
+        increment = abs(increment)
         if start > finish:
-            increment = -abs(increment)
+            increment = -increment
 
+        log.debug(
+            f'fade display {monitor.index} of {monitor.method}'
+            f' {start}->{finish}:{increment}:logarithmic={logarithmic}'
+        )
         for value in range_func(start, finish, increment):
             monitor.set_brightness(value, no_return=True)
             time.sleep(interval)
@@ -234,7 +244,8 @@ def fade_brightness(
             t1 = threading.Thread(target=fade, args=(st, fi, increment, monitor))
             t1.start()
             threads.append(t1)
-        except Exception:
+        except Exception as e:
+            log.debug(f'exception when preparing to fade monitor {i} - {type(e).__name__}: {e}')
             pass
 
     if not blocking:
@@ -600,7 +611,11 @@ class Monitor():
         try:
             self.get_brightness()
             return True
-        except Exception:
+        except Exception as e:
+            log.debug(
+                f'Monitor.is_active: {self.get_identifier()} failed get_brightness call'
+                f' - {type(e).__name__}: {e}'
+            )
             return False
 
 
@@ -716,6 +731,8 @@ def __brightness(
 ):
     '''Internal function used to get/set brightness'''
 
+    log.debug(f"brightness {meta_method} request display {display} with method {method}")
+
     def format_exc(name, e):
         errors.append((
             name, e.__class__.__name__,
@@ -739,13 +756,11 @@ def __brightness(
                         output.append(None)
                         continue
 
-                output.append(monitor['method'].get_brightness(display=monitor['index'], **kwargs))
+                output += monitor['method'].get_brightness(display=monitor['index'], **kwargs)
             except Exception as e:
                 output.append(None)
                 format_exc(monitor, e)
 
-    output = flatten_list(output)
-
     if output:
         output_is_none = set(output) == {None}
         if (
@@ -782,7 +797,5 @@ if platform.system() == 'Windows':
 elif platform.system() == 'Linux':
     from . import linux
     _OS_MODULE = linux
-elif platform.system() == 'Darwin':
-    raise NotImplementedError('MAC is not yet supported')
 else:
-    raise NotImplementedError(f'{platform.system()} is not yet supported')
+    log.warning(f'package imported on unsupported platform ({platform.system()})')
