@@ -8,6 +8,8 @@ import time
 from functools import lru_cache
 from typing import Any, List, Tuple, Union
 
+from ._debug import log
+
 if int(platform.python_version_tuple()[1]) < 9:
     from typing import Generator
 else:
@@ -149,7 +151,7 @@ class EDID:
                     model = name.strip().rsplit(' ', 1)[1]
                 except IndexError:
                     # If the name does not include model information then
-                    # give it somethign generic
+                    # give it something generic
                     model = 'Generic Monitor'
 
         return mfg_id, manufacturer, model, name, serial
@@ -186,6 +188,7 @@ MONITOR_MANUFACTURER_CODES = {
     "ACT": "Targa",
     "ADI": "ADI Corporation",
     "AIC": "AG Neovo",
+    "ALX": "Anrecson",
     "AMW": "AMW",
     "AOC": "AOC",
     "API": "Acer America Corp.",
@@ -305,7 +308,10 @@ def _monitor_brand_lookup(search: str) -> Union[Tuple[str, str], None]:
 
 def flatten_list(thick_list: List[Any]) -> List[Any]:
     '''
-    Internal function I use to flatten lists, because I do that often
+    .. warning:: Deprecated
+       This function has been deprecated and will be removed in version 0.17.0
+
+    Internal function I use to flatten lists, because I do that often.
 
     Args:
         thick_list (list): The list to be flattened. Can be as deep as you wish (within recursion limits)
@@ -358,6 +364,9 @@ def logarithmic_range(start: int, stop: int, step: int = 1) -> Generator[int, No
     else:
         value_range = stop - start
 
+        def direction(x):
+            return x if step > 0 else 100 - x
+
         last_yielded = None
         for x in range(start, stop + 1, step):
             # get difference from base point
@@ -365,9 +374,9 @@ def logarithmic_range(start: int, stop: int, step: int = 1) -> Generator[int, No
             # calculate progress through our range as a percentage
             x = (x / value_range) * 100
             # convert along logarithmic curve (inverse of y = 50log(x)) to another percentage
-            x = 10 ** (x / 50)
+            x = 10 ** (direction(x) / 50)
             # apply this percentage to our range and add back starting offset
-            x = int(((x / 100) * value_range) + start)
+            x = int(((direction(x) / 100) * value_range) + start)
 
             if x == last_yielded:
                 continue
@@ -411,25 +420,31 @@ class __Cache(dict):
             value, expires, orig_args, orig_kwargs = self[key]
             if time.time() < expires:
                 if orig_args == args and orig_kwargs == kwargs:
+                    log.debug(f'cache get {repr(key)}')
                     return value
             else:
+                log.debug(f'cache get {repr(key)} = [expired]')
                 del self[key]
         except KeyError:
+            log.debug(f'cache get {repr(key)} = [KeyError]')
             pass
 
     def store(self, key, value, *args, expires=1, **kwargs):
         self[key] = (value, expires + time.time(), args, kwargs)
+        log.debug(f'cache set {repr(key)}, expires={expires}')
 
     def expire(self, key=None, startswith=None):
         if key is not None:
             try:
                 del self[key]
+                log.debug(f'cache expire key {repr(key)}')
             except KeyError:
                 pass
         elif startswith is not None:
             for i in tuple(self.keys()):
                 if i.startswith(startswith):
                     del self[i]
+                    log.debug(f'cache expire key {repr(i)}')
 
 
 __cache__ = __Cache()
